==> central-repository-3.62.0.zip: com/microej/pack/ui/ui-testsuite/1.3.0/README-1.3.0.md <==
# Overview

MicroEJ Testsuite: `ui-testsuite`.

This library checks the optional APIs of `LLUI_DISPLAY_impl.h`, `LLUI_PAINTER_impl.h` and `LLDW_PAINTER_impl.h`.

## Reference tests

The tests in the packages under `com.microej.microui.test.reference` draw a set of drawings.
The expected results can be compared to screenshots available in the `reference` folder in this project.
For example `com.microej.microui.test.reference.transform.FrameworkImage.testScaleImage()` expected result can be found in `/reference/transform/testScaleImage.png`.

### Image reference tests

The tests in the package `com.microej.microui.test.reference.transform` can be found in the class `FrameworkImage`.
Each test in this class is run for each image type and format (declared in the other classes).

# Usage

Add the following line to your `module.ivy`:

    <dependency org="com.microej.pack.ui" name="ui-testsuite" rev="1.3.0"/>
    
Some tests require an image heap large enough to store one or several frame buffers (a buffer whose size is equal to the framebuffer size: lcd width x lcd height x lcd bpp / 8).
The framebuffer size should be set when launching the testsuite:

* in the `module.ivy` file that fetches the testsuite and the VEE Port:

	<ea:property name="microej.testsuite.properties.ej.microui.memory.framebuffer.size" value="261120"/>

* or in the `common.properties` file that set the common properties when launching the testsuite:

	ej.microui.memory.framebuffer.size=261120

If not set, a default value of 1MB is used (480x480x32/8).
If the VEE Port cannot allocate the expected image heap (too big heap), the associated test cannot be executed and must be explicitely ignored. 

# Requirements

This library requires the following Foundation Libraries:

    BON-1.4, DRAWING-1.0, EDC-1.3, MICROUI-3.0

# Dependencies

_All dependencies are retrieved transitively by MicroEJ Module Manager_.

# Source

N/A.

# Restrictions

None.

---  
_Copyright 2022-2023 MicroEJ Corp. All rights reserved._  
_Use of this source code is governed by a BSD-style license that can be found with this software._

==> central-repository-3.63.0.zip: com/microej/pack/ui/ui-testsuite/14.3.0/README-14.3.0.md <==
# Overview

MicroEJ Testsuite: `ui-testsuite`.

This library checks the optional APIs of `LLUI_DISPLAY_impl.h`, `LLUI_PAINTER_impl.h` and `LLDW_PAINTER_impl.h`.

## Reference tests

The tests in the packages under `com.microej.microui.test.reference` draw a set of drawings.
The expected results can be compared to screenshots available in the `reference` folder in this project.
For example `com.microej.microui.test.reference.transform.FrameworkImage.testScaleImage()` expected result can be found in `/reference/transform/testScaleImage.png`.

### Image reference tests

The tests in the package `com.microej.microui.test.reference.transform` can be found in the class `FrameworkImage`.
Each test in this class is run for each image type and format (declared in the other classes).

## Bench

The description of the test `com.microej.microui.bench.RunBench` is available in the VEE Port Qualification Tools (PQT).

# Usage

Add the following line to your `module.ivy`:

    <dependency org="com.microej.pack.ui" name="ui-testsuite" rev="14.3.0"/>
    
Some tests require an image heap large enough to store one or several frame buffers (a buffer whose size is equal to the framebuffer size: lcd width x lcd height x lcd bpp / 8).
The framebuffer size should be set when launching the testsuite:

* in the `module.ivy` file that fetches the testsuite and the VEE Port:

	<ea:property name="microej.testsuite.properties.ej.microui.memory.framebuffer.size" value="261120"/>

* or in the `common.properties` file that set the common properties when launching the testsuite:

	ej.microui.memory.framebuffer.size=261120

If not set, a default value of 1MB is used (480x480x32/8).
If the VEE Port cannot allocate the expected image heap (too big heap), the associated test cannot be executed and must be explicitely ignored. 

# Requirements

This library requires the following Foundation Libraries:

    BON-1.4, DRAWING-1.0, EDC-1.3, MICROUI-3.5

# Dependencies

_All dependencies are retrieved transitively by MicroEJ Module Manager_.

# Source

N/A.

# Restrictions

None.

---  
_Copyright 2022-2024 MicroEJ Corp. All rights reserved._  
_Use of this source code is governed by a BSD-style license that can be found with this software._
